import classnames from 'classnames';

import { __experimentalColorGradientControl as ColorGradientControl } from '@wordpress/block-editor';

import {
	PanelBody,
	RangeControl,
	SelectControl,
	ToggleControl,
} from '@wordpress/components';

import { Fragment } from '@wordpress/element';
import { __ } from '@wordpress/i18n';

import { divider } from '@smb/helper';

const textureOptions = [
	{
		value: '',
		label: __( 'None', 'snow-monkey-blocks' ),
	},
	{
		value: 'stripe',
		label: __( 'Stripe', 'snow-monkey-blocks' ),
	},
	{
		value: 'noise',
		label: __( 'Noise', 'snow-monkey-blocks' ),
	},
	{
		value: 'dots',
		label: __( 'Dots', 'snow-monkey-blocks' ),
	},
	{
		value: 'dots2',
		label: __( 'Dots 2', 'snow-monkey-blocks' ),
	},
];

const dividerTypeOptions = [
	{
		value: 'tilt',
		label: __( 'Tilt', 'snow-monkey-blocks' ),
	},
	{
		value: 'curve',
		label: __( 'Curve', 'snow-monkey-blocks' ),
	},
	{
		value: 'wave',
		label: __( 'Wave', 'snow-monkey-blocks' ),
	},
	{
		value: 'triangle',
		label: __( 'Triangle', 'snow-monkey-blocks' ),
	},
];

export const PanelSectionMovableBackgroundSettings = ( {
	hasColor,
	disableNoOver,
	hasTexture,
	settings,
} ) => {
	return (
		<PanelBody
			title={ __(
				'Background (Movable) Settings',
				'snow-monkey-blocks'
			) }
			initialOpen={ false }
		>
			{ settings.map( ( setting, index ) => {
				if (
					setting.hasOwnProperty( 'colorValue' ) &&
					setting.hasOwnProperty( 'gradientValue' ) &&
					setting.hasOwnProperty( 'onColorChange' ) &&
					setting.hasOwnProperty( 'onGradientChange' )
				) {
					return (
						<ColorGradientControl
							key={ index }
							label={ __( 'Color', 'snow-monkey-blocks' ) }
							colorValue={ setting.colorValue }
							gradientValue={ setting.gradientValue }
							onColorChange={ setting.onColorChange }
							onGradientChange={ setting.onGradientChange }
						/>
					);
				}

				if ( hasColor ) {
					if (
						setting.hasOwnProperty( 'horizontalPositionValue' ) &&
						setting.hasOwnProperty( 'onHorizontalPositionChange' )
					) {
						return (
							<RangeControl
								key={ index }
								label={ __(
									'Background Position (Left / Right)',
									'snow-monkey-blocks'
								) }
								value={ setting.horizontalPositionValue }
								onChange={ setting.onHorizontalPositionChange }
								min="-90"
								max="90"
							/>
						);
					}

					if (
						setting.hasOwnProperty( 'verticalPositionValue' ) &&
						setting.hasOwnProperty( 'onVerticalPositionChange' )
					) {
						return (
							<RangeControl
								key={ index }
								label={ __(
									'Background Position (Top / Bottom)',
									'snow-monkey-blocks'
								) }
								value={ setting.verticalPositionValue }
								onChange={ setting.onVerticalPositionChange }
								min="-90"
								max="90"
							/>
						);
					}

					if (
						! disableNoOver &&
						setting.hasOwnProperty( 'isNoOverValue' ) &&
						setting.hasOwnProperty( 'onIsNoOverChange' )
					) {
						return (
							<ToggleControl
								key={ index }
								label={ __(
									"Make sure the background doesn't overflow to the outside",
									'snow-monkey-blocks'
								) }
								checked={ setting.isNoOverValue }
								onChange={ setting.onIsNoOverChange }
							/>
						);
					}

					if (
						setting.hasOwnProperty( 'textureValue' ) &&
						setting.hasOwnProperty( 'onTextureChange' )
					) {
						return (
							<SelectControl
								key={ index }
								label={ __( 'Texture', 'snow-monkey-blocks' ) }
								value={ setting.textureValue }
								onChange={ setting.onTextureChange }
								options={ textureOptions }
							/>
						);
					}

					if (
						hasTexture &&
						setting.hasOwnProperty( 'textureOpacityValue' ) &&
						setting.hasOwnProperty( 'onTextureOpacityChange' )
					) {
						return (
							<RangeControl
								key={ index }
								label={ __(
									'Texture Opacity',
									'snow-monkey-blocks'
								) }
								value={ Number(
									setting.textureOpacityValue.toFixed( 1 )
								) }
								onChange={ setting.onTextureOpacityChange }
								min={ 0.1 }
								max={ 1 }
								step={ 0.1 }
							/>
						);
					}
				}

				return <Fragment key={ index }></Fragment>;
			} ) }
		</PanelBody>
	);
};

export const PanelSectionFixedBackgroundSettings = ( {
	hasTexture,
	settings,
} ) => {
	return (
		<PanelBody
			title={ __( 'Background (Fixed) Settings', 'snow-monkey-blocks' ) }
			initialOpen={ false }
		>
			{ settings.map( ( setting, index ) => {
				if (
					setting.hasOwnProperty( 'colorValue' ) &&
					setting.hasOwnProperty( 'gradientValue' ) &&
					setting.hasOwnProperty( 'onColorChange' ) &&
					setting.hasOwnProperty( 'onGradientChange' )
				) {
					return (
						<ColorGradientControl
							key={ index }
							label={ __( 'Color', 'snow-monkey-blocks' ) }
							colorValue={ setting.colorValue }
							gradientValue={ setting.gradientValue }
							onColorChange={ setting.onColorChange }
							onGradientChange={ setting.onGradientChange }
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'textureValue' ) &&
					setting.hasOwnProperty( 'onTextureChange' )
				) {
					return (
						<SelectControl
							key={ index }
							label={ __( 'Texture', 'snow-monkey-blocks' ) }
							value={ setting.textureValue }
							onChange={ setting.onTextureChange }
							options={ textureOptions }
						/>
					);
				}

				if (
					hasTexture &&
					setting.hasOwnProperty( 'textureOpacityValue' ) &&
					setting.hasOwnProperty( 'onTextureOpacityChange' )
				) {
					return (
						<RangeControl
							key={ index }
							label={ __(
								'Texture Opacity',
								'snow-monkey-blocks'
							) }
							value={ Number(
								setting.textureOpacityValue.toFixed( 1 )
							) }
							onChange={ setting.onTextureOpacityChange }
							min={ 0.1 }
							max={ 1 }
							step={ 0.1 }
						/>
					);
				}

				return <Fragment key={ index }></Fragment>;
			} ) }
		</PanelBody>
	);
};

export const PanelSectionTopDividerSettings = ( { settings } ) => {
	return (
		<PanelBody
			title={ __( 'Top divider Settings', 'snow-monkey-blocks' ) }
			initialOpen={ false }
		>
			{ settings.map( ( setting, index ) => {
				if (
					setting.hasOwnProperty( 'typeValue' ) &&
					setting.hasOwnProperty( 'onTypeChange' )
				) {
					return (
						<SelectControl
							key={ index }
							label={ __( 'Type', 'snow-monkey-blocks' ) }
							value={ setting.typeValue }
							onChange={ setting.onTypeChange }
							options={ dividerTypeOptions }
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'levelValue' ) &&
					setting.hasOwnProperty( 'onLevelChange' )
				) {
					return (
						<RangeControl
							key={ index }
							label={ __( 'Level', 'snow-monkey-blocks' ) }
							value={ setting.levelValue }
							onChange={ setting.onLevelChange }
							min="-100"
							max="100"
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'colorValue' ) &&
					setting.hasOwnProperty( 'onColorChange' )
				) {
					return (
						<ColorGradientControl
							key={ index }
							label={ __( 'Color', 'snow-monkey-blocks' ) }
							colorValue={ setting.colorValue }
							onColorChange={ setting.onColorChange }
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'verticalPosition' ) &&
					setting.hasOwnProperty( 'onVerticalPositionChange' )
				) {
					return (
						<RangeControl
							key={ index }
							label={ __(
								'Position (Top / Bottom)',
								'snow-monkey-blocks'
							) }
							value={ setting.verticalPosition }
							onChange={ setting.onVerticalPositionChange }
							min="-90"
							max="90"
						/>
					);
				}

				return <Fragment key={ index }></Fragment>;
			} ) }
		</PanelBody>
	);
};

export const PanelSectionBottomDividerSettings = ( { settings } ) => {
	return (
		<PanelBody
			title={ __( 'Bottom divider Settings', 'snow-monkey-blocks' ) }
			initialOpen={ false }
		>
			{ settings.map( ( setting, index ) => {
				if (
					setting.hasOwnProperty( 'typeValue' ) &&
					setting.hasOwnProperty( 'onTypeChange' )
				) {
					return (
						<SelectControl
							key={ index }
							label={ __( 'Type', 'snow-monkey-blocks' ) }
							value={ setting.typeValue }
							onChange={ setting.onTypeChange }
							options={ dividerTypeOptions }
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'levelValue' ) &&
					setting.hasOwnProperty( 'onLevelChange' )
				) {
					return (
						<RangeControl
							key={ index }
							label={ __( 'Level', 'snow-monkey-blocks' ) }
							value={ setting.levelValue }
							onChange={ setting.onLevelChange }
							min="-100"
							max="100"
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'colorValue' ) &&
					setting.hasOwnProperty( 'onColorChange' )
				) {
					return (
						<ColorGradientControl
							key={ index }
							label={ __( 'Color', 'snow-monkey-blocks' ) }
							colorValue={ setting.colorValue }
							onColorChange={ setting.onColorChange }
						/>
					);
				}

				if (
					setting.hasOwnProperty( 'verticalPositionValue' ) &&
					setting.hasOwnProperty( 'onVerticalPositionChange' )
				) {
					return (
						<RangeControl
							key={ index }
							label={ __(
								'Position (Top / Bottom)',
								'snow-monkey-blocks'
							) }
							value={ setting.verticalPositionValue }
							onChange={ setting.onVerticalPositionChange }
							min="-90"
							max="90"
						/>
					);
				}

				return <Fragment key={ index }></Fragment>;
			} ) }
		</PanelBody>
	);
};

export const SectionBackground = ( {
	backgroundHorizontalPosition,
	backgroundVerticalPosition,
	isBackgroundNoOver,
	backgroundColor,
	backgroundGradientColor,
	backgroundTexture,
	backgroundTextureOpacity,
	fixedBackgroundColor,
	fixedBackgroundGradientColor,
	fixedBackgroundTexture,
	fixedBackgroundTextureOpacity,
	topDividerType,
	topDividerLevel,
	topDividerColor,
	topDividerVerticalPosition,
	bottomDividerType,
	bottomDividerLevel,
	bottomDividerColor,
	bottomDividerVerticalPosition,
} ) => {
	const hasBackgroundColor = !! backgroundColor || !! backgroundGradientColor;
	const hasBackgroundTexture = !! backgroundTexture;
	const hasFixedBackgroundColor =
		!! fixedBackgroundColor || !! fixedBackgroundGradientColor;
	const hasFixedBackgroundTexture = !! fixedBackgroundTexture;
	const hasTopDivider = !! topDividerLevel;
	const hasBottomDivider = !! bottomDividerLevel;

	const topDividerClasses = classnames(
		'smb-section__divider',
		'smb-section__divider--top',
		`smb-section__divider--${ topDividerType }`
	);

	const bottomDividerClasses = classnames(
		'smb-section__divider',
		'smb-section__divider--bottom',
		`smb-section__divider--${ bottomDividerType }`
	);

	const backgroundStyles = {};
	if ( hasBackgroundColor ) {
		backgroundStyles.backgroundColor = backgroundColor;
		backgroundStyles.backgroundImage = backgroundGradientColor;

		if ( ! isBackgroundNoOver ) {
			if ( backgroundHorizontalPosition || backgroundVerticalPosition ) {
				backgroundStyles.transform = `translate(${
					backgroundHorizontalPosition || 0
				}%, ${ backgroundVerticalPosition || 0 }%)`;
			}
		} else {
			if ( 0 < backgroundHorizontalPosition ) {
				backgroundStyles.left = `${ Math.abs(
					backgroundHorizontalPosition
				) }%`;
			} else if ( 0 > backgroundHorizontalPosition ) {
				backgroundStyles.right = `${ Math.abs(
					backgroundHorizontalPosition
				) }%`;
			}

			if ( 0 < backgroundVerticalPosition ) {
				backgroundStyles.top = `${ Math.abs(
					backgroundVerticalPosition
				) }%`;
			} else if ( 0 > backgroundVerticalPosition ) {
				backgroundStyles.bottom = `${ Math.abs(
					backgroundVerticalPosition
				) }%`;
			}
		}
	}

	const backgroundTextureStyles = {
		backgroundImage: hasBackgroundTexture
			? `url(${ smb.pluginUrl }/dist/block/section/img/${ backgroundTexture }.png)`
			: undefined,
		opacity: !! backgroundTextureOpacity
			? backgroundTextureOpacity
			: undefined,
	};

	const fixedBackgroundStyles = {
		paddingTop: Math.abs( topDividerLevel ),
		paddingBottom: Math.abs( bottomDividerLevel ),
		backgroundColor: fixedBackgroundColor,
		backgroundImage: fixedBackgroundGradientColor,
	};

	const fixedBackgroundTextureStyles = {
		backgroundImage: hasFixedBackgroundTexture
			? `url(${ smb.pluginUrl }/dist/block/section/img/${ fixedBackgroundTexture }.png)`
			: undefined,
		opacity: !! fixedBackgroundTextureOpacity
			? fixedBackgroundTextureOpacity
			: undefined,
	};

	const dividersStyles = {};
	if ( topDividerVerticalPosition ) {
		dividersStyles.top = `${ topDividerVerticalPosition }%`;
	}
	if ( bottomDividerVerticalPosition ) {
		dividersStyles.bottom = `${ bottomDividerVerticalPosition }%`;
	}

	return (
		<>
			{ ( hasFixedBackgroundColor ||
				hasFixedBackgroundTexture ||
				hasBackgroundColor ||
				hasBackgroundTexture ||
				hasTopDivider ||
				hasBottomDivider ) && (
				<div
					className="smb-section__fixed-background"
					style={ fixedBackgroundStyles }
				>
					{ hasFixedBackgroundTexture && (
						<div
							className="smb-section__fixed-background__texture"
							style={ fixedBackgroundTextureStyles }
						/>
					) }

					{ ( hasBackgroundColor || hasBackgroundTexture ) && (
						<div
							className="smb-section__background"
							style={ backgroundStyles }
						>
							{ hasBackgroundTexture && (
								<div
									className="smb-section__background__texture"
									style={ backgroundTextureStyles }
								/>
							) }
						</div>
					) }

					{ ( hasTopDivider || hasBottomDivider ) && (
						<div
							className="smb-section__dividers"
							style={ dividersStyles }
						>
							{ hasTopDivider && (
								<div className={ topDividerClasses }>
									{ divider(
										topDividerType,
										topDividerLevel,
										topDividerColor
									) }
								</div>
							) }

							{ hasBottomDivider && (
								<div className={ bottomDividerClasses }>
									{ divider(
										bottomDividerType,
										bottomDividerLevel,
										bottomDividerColor
									) }
								</div>
							) }
						</div>
					) }
				</div>
			) }
		</>
	);
};
